@@ -4,7 +4,7 @@ use warnings;
 use strict;
 require DateTime::Format::Human::Duration::Locale;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 use Carp qw/croak/;
 
@@ -115,6 +115,9 @@ sub format_duration {
         }
 
         push(@parts, $val . ' ' . $setup->{$setup_key});
+        if (exists $args{'significant_units'}) {
+            last if scalar(@parts) == $args{'significant_units'};
+        }
     }
     
     my $no_time = exists $args{'no_time'} ? $args{'no_time'} : $setup->{'no_time'};
@@ -178,13 +181,13 @@ Create span object, no args
 
 First argument is a DateTime::Duration object
 
-After that you can optionally pass some 'standard args' as a hash as described below
+After that you can optionally pass some L</standard args> as a hash as described below
 
 =head2 format_duration_between()
 
 First two args are DateTime objects
 
-After that you can optionally pass some 'standard args' as a hash as described below
+After that you can optionally pass some L</standard args> as a hash as described below
 
 =head2 standard args
 
@@ -272,6 +275,22 @@ Example:
     print $fmt->format_duration($d, 'precision' => 'days');
     # '1 year, 7 months, 2 weeks, and 2 days'
 
+=item * significant_units
+
+By default, the duration will be formatted using all specified units.  To restrict the number of units output, set this to a value of one or more.
+
+Example:
+
+    my $fmt = DateTime::Format::Human::Duration->new();
+    my $d = DateTime::Duration->new(...);
+  
+    print $fmt->format_duration($d, 'significant_units' => 1);
+    # '3 days'
+    print $fmt->format_duration($d, 'significant_units' => 2);
+    # '3 days and 10 hours'
+    print $fmt->format_duration($d, 'significant_units' => 3);
+    # '3 days, 10 hours, and 27 minutes'
+
 =back
 
 =back
@@ -325,7 +344,7 @@ Takes no arguments, should return a hashref of this structure:
 
 Try to use L</get_human_span_hashref()> if the locale allows for it since it's much easier. If you cannot, however, then this will give you the maximum level of configurability.
 
-This takes the arguments as described in the example below, should return the localized "span" string.
+This function receives a hashref of duration values, and a hashref of the L</standard args>. It should return the localized string.
 
     sub get_human_span_from_units {
         my ($duration_values_hr, $args_hr) = @_;
@@ -333,7 +352,7 @@ This takes the arguments as described in the example below, should return the lo
         return $string; # 1 year, 2days, 4 hours, and 17 minutes
     }
 
-    Please see the example in C<t/lib/DateTime/Format/Human/Duration/Locale/nb.pm>.
+Please see the example in C<t/lib/DateTime/Format/Human/Duration/Locale/nb.pm>.
 
 =back
 
